@@ -1,4 +1,4 @@
-# $Id: Config.pm,v 1.42.2.1 2003/02/15 09:36:24 joern Exp $
+# $Id: Config.pm,v 1.42.2.2 2003/03/03 11:59:25 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -19,6 +19,8 @@ use FileHandle;
 use Data::Dumper;
 use Carp;
 
+my $DEFAULT_FILENAME = "$ENV{HOME}/.dvdriprc";
+
 sub config			{ shift->{config}			}
 
 sub order			{ shift->{order}			}
@@ -478,8 +480,7 @@ sub new {
 sub load {
 	my $self = shift;
 	
-	my $filename = $self->filename;
-	die "no filename set" if not $filename;
+	my $filename = $self->filename || $DEFAULT_FILENAME;
 	die "can't read $filename" if not -r $filename;
 	
 	my $loaded;
@@ -526,15 +527,14 @@ sub get_save_data {
 sub save {
 	my $self = shift; $self->trace_in;
 	
-	my $filename = $self->filename;
-	die "not filename set" if not $filename;
+	my $filename = $self->filename || $DEFAULT_FILENAME;
 	
 	my $data_sref = $self->get_save_data;
 	
 	my $fh = FileHandle->new;
 
 	open ($fh, "> $filename") or die "can't write $filename";
-	print $fh q{# $Id: Config.pm,v 1.42.2.1 2003/02/15 09:36:24 joern Exp $},"\n";
+	print $fh q{# $Id: Config.pm,v 1.42.2.2 2003/03/03 11:59:25 joern Exp $},"\n";
 	print $fh "# This file was generated by Video::DVDRip Version $Video::DVDRip::VERSION\n\n";
 
 	print $fh ${$data_sref};
